==> igniteui-angular-charts-18.2.0.tgz: package/esm5/lib/SeriesFocusHighlightingManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HighlightingManager } from "igniteui-angular-core";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesFocusHighlightingManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesFocusHighlightingManager, _super);
    function SeriesFocusHighlightingManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesFocusHighlightingManager.prototype.isCrossContextHighlight = function (a) {
        var b = a;
        if (b.co == 3 || b.co == 4) {
            return true;
        }
        return false;
    };
    SeriesFocusHighlightingManager.prototype.isContextValid = function (a) {
        var b = a;
        return b != null && b.db != null;
    };
    SeriesFocusHighlightingManager.$t = markType(SeriesFocusHighlightingManager, 'SeriesFocusHighlightingManager', HighlightingManager.$);
    return SeriesFocusHighlightingManager;
}(HighlightingManager));
export { SeriesFocusHighlightingManager };

==> igniteui-angular-charts-20.0.0.tgz: package/esm5/lib/SeriesFocusHighlightingManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HighlightingManager } from "igniteui-angular-core";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesFocusHighlightingManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesFocusHighlightingManager, _super);
    function SeriesFocusHighlightingManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesFocusHighlightingManager.prototype.isCrossContextHighlight = function (a) {
        var b = a;
        if (b.cp == 3 || b.cp == 4) {
            return true;
        }
        return false;
    };
    SeriesFocusHighlightingManager.prototype.isContextValid = function (a) {
        var b = a;
        return b != null && b.dc != null;
    };
    SeriesFocusHighlightingManager.$t = markType(SeriesFocusHighlightingManager, 'SeriesFocusHighlightingManager', HighlightingManager.$);
    return SeriesFocusHighlightingManager;
}(HighlightingManager));
export { SeriesFocusHighlightingManager };
